%define  bootstrap  0

# Allow --with[out] bootstrap at rpm command line build
%{?_without_bootstrap: %{expand: %%define bootstrap 0}}
%{?_with_bootstrap: %{expand: %%define bootstrap 1}}

Name:    xinit
Version: 1.3.3
Release: %mkrel 3
Summary: Initialize an X session
License: MIT
Group:   System/X11

URL:     http://cgit.freedesktop.org/xorg/app/xinit
Source0: http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.bz2

# (fc) 1.0.2-2mdv readd modifications for startx (argument parsing)
# This patch is part of the old "startx" patch.
# We need to check why exactly this patch is needed, but it does these things:
# - it removes the default client and server from the startx arguments, so if
#   nothing is specified the default server or client will be the one chosen by
#   xinit
# - it uses trap to make sure the "cleanup" function will be run
# - it partially undoes upstream commit 9632367abd03108f3636b05e9f2fd92f5c28dabe
# - it enables commands like "startx startxfce4", which don't work in the
#   unpatched version (should be "startx /usr/bin/startxfce4")
#Previous versions of this patch had a bug where xinit would be run twice if some
#macros were defined.
Patch0: xinit-1.3.2-startx-arguments.patch

# (fc) prevent freeze from applications trying to read stdin (Fedora bug #214649)
Patch2: xinit-1.0.4-client-session.patch

# (fc) unset XDG_SESSION_COOKIE in startx (Fedora bug #489999)
Patch3: xinit-1.0.9-unset.patch

# (pz) this patch was taken from the old startx.patch
Patch4: xinit-1.2.0-replace-xterm-for-xvt.patch

# (cg) use the current vt to maintain the current session status.
Patch5: xinit-1.3.2-use-current-vt.patch

# (eatdirt) fix bug #12169 with upstream patch
Patch6: xinit-1.3.3-cpprules.patch

# (eatdirt) add subdir-objects to configure.ac to fix autoreconf
Patch7: xinit-1.3.3-subdir.patch

BuildRequires: libx11-devel >= 1.0.0
BuildRequires: x11-util-macros >= 1.0.1
Requires:      xinitrc

%if !%{bootstrap}
Requires:      which
%endif


%description
The xinit program is used to start the X Window System server and a first
client program on systems that cannot start X directly from /etc/init or in
environments that use multiple window systems. When this first client exits,
xinit will kill the X server and then terminate.


%prep
%setup -q -n %{name}-%{version}
%patch0 -p0 -b .orig

%patch2 -p1 -b .client-session
%patch3 -p1 -b .unset
%patch4 -p1 -b .xvt
%patch5 -p1 -b .curvt
%patch6 -p1 -b .cpprules
%patch7 -p1 -b .subdir

#needed by patch1
#if !%{bootstrap}
#autoreconf -fi
#endif

%build
autoreconf
%configure2_5x
%make XINITDIR=/etc/X11/xinit

%install
rm -rf %{buildroot}
%makeinstall_std

#don't use xorg xinitrc file, use our own, provided by xinitrc package
rm -fr %buildroot{%{_libdir},%{_sysconfdir}}/X11/xinit/xinitrc

%files
%{_bindir}/xinit
%{_bindir}/startx
%if !%{bootstrap}
%endif
%{_mandir}/man1/startx.1*
%{_mandir}/man1/xinit.1*




%changelog
* Fri Jan 03 2014 eatdirt <eatdirt> 1.3.3-3.mga4
+ Revision: 564052
- Fix empty lines before #!/bin/sh (bug #12169)

* Sat Oct 19 2013 umeabot <umeabot> 1.3.3-2.mga4
+ Revision: 534484
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 tv <tv> 1.3.3-1.mga4
+ Revision: 477987
- fix build
- new release

* Mon Jan 14 2013 umeabot <umeabot> 1.3.2-5.mga3
+ Revision: 387057
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 19 2012 ovitters <ovitters> 1.3.2-4.mga3
+ Revision: 308235
- drop consolekit support (+1'ed by coling)
- clean spec

* Fri Apr 06 2012 colin <colin> 1.3.2-3.mga2
+ Revision: 229253
- Nicer way to get current tty

* Fri Apr 06 2012 colin <colin> 1.3.2-2.mga2
+ Revision: 229209
- Attempt to detect and reuse the current vt (to preserve login session 'active' status and thus permissions)

* Sat Feb 25 2012 eatdirt <eatdirt> 1.3.2-1.mga2
+ Revision: 214628
- Upgrade to 1.3.2, startx patch fixed

  + tv <tv>
    - new release

* Fri Jan 21 2011 ennael <ennael> 1.3.0-1.mga1
+ Revision: 27603
- imported package xinit


* Tue Jan 11 2011 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.3.0-1mdv2011.0
+ Revision: 630941
- New version: 1.3.0

* Sat Dec 04 2010 Funda Wang <fwang@mandriva.org> 1.2.1-2mdv2011.0
+ Revision: 609520
- update file list

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

* Wed Mar 17 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.2.1-1mdv2010.1
+ Revision: 523766
- New version: 1.2.1

* Wed Nov 25 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.2.0-3mdv2010.1
+ Revision: 470082
- Remake startx-arguments.patch, now undoing an upstream commit

* Tue Nov 24 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.2.0-2mdv2010.1
+ Revision: 469790
- Fix startx-arguments.patch

* Tue Nov 24 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.2.0-1mdv2010.1
+ Revision: 469573
- New version: 1.2.0
  Split startx.patch into startx-arguments.patch and replace-xterm-for-xvt.patch
  Tried to document startx-arguments.patch
  Fixed a possible bug in startx-arguments.patch (documented inside it)
  Rediff unset.patch

* Fri Nov 20 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.1.0-7mdv2010.1
+ Revision: 467738
- Update startx.patch: fix manpage to reflect code changes

* Mon Nov 16 2009 Olivier Blin <oblin@mandriva.com> 1.1.0-6mdv2010.1
+ Revision: 466572
- disable poke-ck patch (like in Fedora package, since we have ck-xinit-session support)

* Wed Sep 23 2009 Frederic Crozat <fcrozat@mandriva.com> 1.1.0-5mdv2010.0
+ Revision: 447761
- Update source1 to correctly set XDG cookie for dbus started services (Fedora)

* Wed Jun 10 2009 Frederic Crozat <fcrozat@mandriva.com> 1.1.0-4mdv2010.0
+ Revision: 384836
- Source1 (Fedora): allow to init CK easily (for XDM)
- Patch3 (Fedora): unset XDG_SESSION_COOKIE in startx (Fedora bug #489999)

* Mon Apr 13 2009 Funda Wang <fwang@mandriva.org> 1.1.0-3mdv2009.1
+ Revision: 366689
- rediff poke-ck patch

  + Antoine Ginies <aginies@mandriva.com>
    - rebuild

* Fri Jun 20 2008 Pixel <pixel@mandriva.com> 1.1.0-2mdv2009.0
+ Revision: 227469
- xinit must get its config files from /etc/X11/xinit
  (used to work using symlink /usr/lib/X11/xinit -> ../../../../etc/X11/xinit)

* Mon Jun 16 2008 Thierry Vignaud <tv@mandriva.org> 1.1.0-1mdv2009.0
+ Revision: 219399
- new release (rediff patch 0)

* Wed May 28 2008 Thierry Vignaud <tv@mandriva.org> 1.0.9-1mdv2009.0
+ Revision: 212579
- new release (rediff patch 0)

* Thu May 08 2008 Helio Chissini de Castro <helio@mandriva.com> 1.0.8-2mdv2009.0
+ Revision: 204696
- Wrong symlink create conflicts with xinitrc and breaking compilations and updates

* Tue Apr 15 2008 Thierry Vignaud <tv@mandriva.org> 1.0.8-1mdv2009.0
+ Revision: 194283
- rediff patch 0
- new release
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Oct 09 2007 Thierry Vignaud <tv@mandriva.org> 1.0.7-1mdv2008.1
+ Revision: 96064
- new release

  + Frederic Crozat <fcrozat@mandriva.com>
    - Patch1 (Fedora):  prevent freeze from applications trying to read stdin (Fedora bug #214649)

* Fri Jul 27 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.4-2mdv2008.0
+ Revision: 56403
-Patch1 (Fedora): add ConsoleKit support
-Fix build with lzma manpages

* Fri Jun 22 2007 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.0.4-1mdv2008.0
+ Revision: 43204
- New upstream release: 1.0.4
- Remove setuid security fix (applied upstream)
- Removed signal catching part of the startx patch: applied upstream


* Fri Feb 16 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-6mdv2007.0
+ Revision: 121690
- Add requires on xinitrc package

* Sat Sep 02 2006 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.0.2-5mdv2007.0
+ Revision: 59272
- add a patch to check setuid return value to make sure we drop user
  privilegies (#24976)

* Thu Aug 17 2006 Pixel <pixel@mandriva.com> 1.0.2-4mdv2007.0
+ Revision: 56303
- fix group
- xvt can be konsole, and konsole does not handle -n xxx

  + Gustavo Pichorim Boiko <boiko@mandriva.com>
    - rebuild to fix cooker uploading
    - X11R7.1
    - increment release
    - Adding X.org 7.0 to the repository

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix spacing
    - fill in a couple of missing descriptions

  + Frederic Crozat <fcrozat@mandriva.com>
    - * don't ship xorg initrc file, link to our own version and requires xinitrc
      * re-add startx patch to allow specifying desktop environment on commandline

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

  + Laurent Montel <lmontel@mandriva.com>
    - Conflict with xinitrc (allow to upgrade it)

